#[non_exhaustive]pub enum DiagnosticStage {
Parse,
Read,
Canonicalize,
Validate,
Transform,
Build,
Emit,
Bind,
Partner,
Request,
}Expand description
The common module records and containers. These explicit facade exports keep ordinary callers out of the component crate paths. Pipeline stage encoded by the first segment of a diagnostic code.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Implementations
Sourceimpl DiagnosticStage
impl DiagnosticStage
pub const ALL: &'static [DiagnosticStage]
pub const NAMESPACES: &'static [&'static str]
pub const fn namespace(self) -> &'static str
pub fn from_namespace(namespace: &str) -> Option<DiagnosticStage>