#[non_exhaustive]pub enum UnresolvedMonitorReason {
NoSuchSubsystem,
NoSuchBranch {
from: BusId,
to: BusId,
circuit: String,
},
AmbiguousBranch {
from: BusId,
to: BusId,
circuit: String,
matches: usize,
},
}Expand description
Why a monitor statement named nothing.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
NoSuchSubsystem
The subsystem set states no subsystem of that name.
NoSuchBranch
AmbiguousBranch
The terminal pair and circuit id name more than one branch.