deserialize

Function deserialize 

pub fn deserialize(input: impl IntoSource) -> Result<PioModule<PioValue>, Error>
Deserialize one PowerIO IR input: a file name, content in memory, or a powerio_core::Source.

Errors

The source is not one UTF-8 IR document, or its schema is unsupported or invalid.