serialize

Function serialize 

pub fn serialize<T>(
    module: &PioModule<T>,
    output: impl IntoDestination,
) -> Result<EmitResult, Error>
where T: Clone + Into<PioValue>,
Serialize a dynamic module as PowerIO IR.

PowerIO IR is the durable representation of a complete PioModule. It is separate from the grid exchange formats handled by crate::emit.

Errors

The module cannot be represented by the current IR schema, or the destination refuses the artifact.