pub struct AutomaticSpec {
pub order: AutomaticOrder,
pub target: AutomaticTarget,
pub subsystem: String,
pub low_voltage_3w: bool,
}Expand description
A specification that expands into one case per element of a subsystem.
Fields
order: AutomaticOrdertarget: AutomaticTargetsubsystem: StringThe subsystem the expansion draws elements from.
low_voltage_3w: bool3WLOWVOLTAGE: include the low voltage winding of a three winding
transformer in a branch expansion.