pub struct FormatId(/* private fields */);Expand description
The common module records and containers. These explicit facade exports keep ordinary callers out of the component crate paths. Open stable identifier used to select a parser or writer.
Implementations