HistoryEntry

Struct HistoryEntry 

pub struct HistoryEntry { /* private fields */ }
The common module records and containers. These explicit facade exports keep ordinary callers out of the component crate paths. Structured description of an operation that produced the current value.

Implementations

Source

impl HistoryEntry

pub fn new( id: HistoryId, kind: HistoryKind, name: impl Into<String>, ) -> Result<HistoryEntry, Error>

pub fn id(&self) -> &HistoryId

pub const fn kind(&self) -> HistoryKind

pub fn name(&self) -> &str

pub fn input_type(&self) -> Option<&str>

pub fn output_type(&self) -> Option<&str>

pub const fn parameters(&self) -> &BTreeMap<String, Value>

pub fn assumptions(&self) -> &[String]

pub fn losses(&self) -> &[String]

pub fn with_input_type( self, type_name: impl Into<String>, ) -> Result<HistoryEntry, Error>

pub fn with_output_type( self, type_name: impl Into<String>, ) -> Result<HistoryEntry, Error>

pub fn with_parameters( self, parameters: BTreeMap<String, Value>, ) -> Result<HistoryEntry, Error>

pub fn with_assumption( self, assumption: impl Into<String>, ) -> Result<HistoryEntry, Error>

pub fn with_loss(self, loss: impl Into<String>) -> Result<HistoryEntry, Error>