pub struct SkipRule {
pub from: BusId,
pub to: BusId,
pub circuit: String,
}Expand description
One branch an automatic expansion leaves alone.
Fields
from: BusIdto: BusIdcircuit: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for SkipRule
impl<'de> Deserialize<'de> for SkipRule
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<SkipRule, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<SkipRule, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SkipRule
Sourceimpl JsonSchema for SkipRule
impl JsonSchema for SkipRule
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for SkipRule
impl Serialize for SkipRule
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for SkipRule