pub struct SourceMapEntry { /* private fields */ }Expand description
The common module records and containers. These explicit facade exports keep ordinary callers out of the component crate paths. Relation between one typed value target and its source bytes.
Implementations
Sourceimpl SourceMapEntry
impl SourceMapEntry
pub fn new( target: impl Into<String>, relation: SourceRelation, spans: Vec<SourceSpan>, ) -> Result<SourceMapEntry, Error>
pub fn target(&self) -> &str
pub const fn relation(&self) -> SourceRelation
pub fn spans(&self) -> &[SourceSpan]