#[non_exhaustive]pub struct UnresolvedAction {
pub action: ContingencyAction,
pub reason: UnresolvedReason,
}Expand description
One action that bound to nothing, kept with the reason.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.action: ContingencyActionreason: UnresolvedReasonTrait Implementations
Sourceimpl Clone for UnresolvedAction
impl Clone for UnresolvedAction
Sourcefn clone(&self) -> UnresolvedAction
fn clone(&self) -> UnresolvedAction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UnresolvedAction
impl Debug for UnresolvedAction
Sourceimpl PartialEq for UnresolvedAction
impl PartialEq for UnresolvedAction
Sourcefn eq(&self, other: &UnresolvedAction) -> bool
fn eq(&self, other: &UnresolvedAction) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for UnresolvedAction