pub fn resolve_format(name: &str) -> Option<FormatInfo>Expand description
Resolve a format token or common alias to facade owned metadata.
This includes transmission and distribution grid exchange formats, the standalone geographic layer document, and the three PSS/E contingency analysis files. PowerIO IR is not a grid exchange format and therefore is not returned here.